package WWW::GameFAQs::Archive::Options;

=head1 COPYRIGHT

Copyright 2010 Kodi Arfer.

This program is free software. You may copy or redistribute it under the same terms as Perl itself.

=cut

use DateTime::TimeZone;
use CGI::Minimal;
use CGI::Cookie;
use WWW::GameFAQs::Archive::Internal
    qw(htmlsafe time_zone read_time_zone);

use parent 'Exporter';
@WWW::GameFAQs::Archive::Options::EXPORT_OK =
    qw(options_page);

sub options_page
#
# ~~~Mandatory arguments
# here => url
#
# ~~~CGI parameters
# time_zone => string
#
# ~~~Returns
# (HTTP header, HTML)
#
   {my %o = @_;

    my $c = new CGI::Minimal;
    my $tz;
    my ($cookie, $msg) =
        ! ($tz = $c->param('time_zone'))
      ? (undef, '', '')
      : ! ($tz = read_time_zone $c->param('time_zone'))
      ? ('', sprintf '<strong>Error:</strong> %s.',
          'Argument not a valid time-zone name')
      : (sprintf("Set-Cookie: %s\n", new CGI::Cookie
             (-name => 'wgfa_time_zone',
              -value => $tz,
              -expires => 'Tuesday, 19-Jan-2038 03:14:07 GMT')),
          'Cookie sent.');

    my @names = sort {$a cmp $b} DateTime::TimeZone->all_names, 'UTC';
    $tz or $tz = time_zone;
    return ($cookie, sprintf
        "%s<form action='%s'>\n" .
            "<p><label for='wgfa_time_zone'>Time zone: </label>\n" .
            "<select name='time_zone' id='wgfa_time_zone'>%s</select>\n" .
            "<br>\n" .
            "<button type='submit'>Set</button></p></form>\n",
       $msg && sprintf("<div class='%s %s'>%s</div>\n",
           'wgfa-options-reply',
           $cookie ? 'wgfa-notification' : 'wgfa-error',
           "<span>$msg</span>"),
       htmlsafe($o{here}),
       join('', map {sprintf "<option%s>$_", $tz eq $_
               ? ' selected'
               : ''}
            @names));}

1;
